@@ -427,6 +427,17 @@ static void curve_group_mul(element_ptr x, element_ptr a, element_ptr b)
     point_add(x->data, a->data, b->data);
 }
 
+static void curve_group_div(element_ptr x, element_ptr a, element_ptr b)
+{
+    if (a == b) {
+	point_set_inf(x->data);
+    } else {
+	point_neg(b->data, b->data);
+	point_add(x->data, a->data, b->data);
+	point_neg(b->data, b->data);
+    }
+}
+
 static void curve_group_set1(element_ptr x)
 {
     point_set_inf(x->data);
@@ -483,6 +494,16 @@ static int curve_group_from_bytes(element_t e, unsigned char *data)
     return len;
 }
 
+static void curve_group_print_info(FILE *out, field_t f)
+{
+    int len;
+    fprintf(out, "Group of points on elliptic curve");
+    if ((len = f->fixed_length_in_bytes)) {
+	fprintf(out, ", bits per coord = %d", len * 8 / 2);
+    }
+    fprintf(out, "\n");
+}
+
 void field_clear_curve_group(field_t f)
 {
     curve_group_data_ptr p;
@@ -503,6 +524,7 @@ void field_init_curve_group(field_t f, curve_t c, mpz_t cofac)
     f->clear = curve_group_clear;
     f->neg = f->invert = curve_group_invert;
     f->add = f->mul = curve_group_mul;
+    f->sub = curve_group_div;
     f->set0 = f->set1 = curve_group_set1;
     f->set = curve_group_set;
     f->random = curve_group_random;
@@ -516,6 +538,7 @@ void field_init_curve_group(field_t f, curve_t c, mpz_t cofac)
     }
     f->to_bytes = curve_group_to_bytes;
     f->from_bytes = curve_group_from_bytes;
+    f->print_info = curve_group_print_info;
 }
 
 //singular with node: y^2 = x^3 + x^2
