@@ -1,9 +1,11 @@
+// requires
+// * stdio.h
+// * gmp.h
+// * pairing.h
+// * fops.h
 #ifndef E_PARAM_H
 #define E_PARAM_H
 
-#include "pairing.h"
-#include "fops.h"
-
 struct e_param_s {
     mpz_t q; //curve defined over F_q
     mpz_t r; //q = h r^2 + 1, r is prime
